Module binary_view_map

Module binary_view_map 

ArrowBytesViewMap and ArrowBytesViewSet for storing maps/sets of values from StringViewArray/BinaryViewArray.

Structs

ArrowBytesViewMap
ArrowBytesViewSet
HashSet optimized for storing string or binary values that can produce that the final set as a GenericBinaryViewArray with minimal copies.