MetricsSet

Struct MetricsSet 

pub struct MetricsSet { /* private fields */ }
A snapshot of the metrics for a particular execution plan.

Implementations

Source

impl MetricsSet

pub fn new() -> Self

Create a new container of metrics

pub fn push(&mut self, metric: Arc<Metric>)

Add the specified metric

pub fn iter(&self) -> impl Iterator<Item = &Arc<Metric>>

Returns an iterator across all metrics

pub fn output_rows(&self) -> Option<usize>

Convenience: return the number of rows produced, aggregated across partitions or None if no metric is present

pub fn spill_count(&self) -> Option<usize>

Convenience: return the count of spills, aggregated across partitions or None if no metric is present

pub fn spilled_bytes(&self) -> Option<usize>

Convenience: return the total byte size of spills, aggregated across partitions or None if no metric is present

pub fn spilled_rows(&self) -> Option<usize>

Convenience: return the total rows of spills, aggregated across partitions or None if no metric is present

pub fn elapsed_compute(&self) -> Option<usize>

Convenience: return the amount of elapsed CPU time spent, aggregated across partitions or None if no metric is present

pub fn sum<F>(&self, f: F) -> Option<MetricValue>
where F: FnMut(&Metric) -> bool,

Sums the values for metrics for which f(metric) returns true, and returns the value. Returns None if no metrics match the predicate.

pub fn sum_by_name(&self, metric_name: &str) -> Option<MetricValue>

Returns the sum of all the metrics with the specified name in the returned set.

pub fn aggregate_by_name(&self) -> Self

Returns a new derived MetricsSet where all metrics that had the same name have been aggregated together. The resulting MetricsSet has all metrics with Partition=None

pub fn sorted_for_display(self) -> Self

Sort the order of metrics so the “most useful” show up first

pub fn timestamps_removed(self) -> Self

Remove all timestamp metrics (for more compact display)

pub fn filter_by_metric_types(self, allowed: &[MetricType]) -> Self

Returns a new derived MetricsSet containing only metrics whose MetricType appears in allowed.

pub fn filter_by_categories(self, allowed: &[MetricCategory]) -> Self

Returns a new MetricsSet filtered by MetricCategory.

  • Metrics that declared a category are kept only when that category appears in allowed.
  • Metrics with no declared category are treated as Uncategorized for filtering.
  • An empty allowed slice means “plan only”: all metrics are removed.