Module sort_expr

Module sort_expr 

Sort expressions

Structs

LexOrdering
This object represents a lexicographical ordering and contains a vector of PhysicalSortExpr objects.
LexRequirement
This object represents a lexicographical ordering requirement and contains a vector of PhysicalSortRequirement objects.
PhysicalSortExpr
Represents Sort operation for a column in a RecordBatch
PhysicalSortRequirement
Represents sort requirement associated with a plan

Enums

OrderingRequirements
Represents a plan’s input ordering requirements. Vector elements represent alternative ordering requirements in the order of preference. The list of alternatives can be either hard or soft, depending on whether the operator can work without an input ordering.

Functions

format_physical_sort_requirement_list
Writes a list of PhysicalSortRequirements to a std::fmt::Formatter.
is_reversed_sort_options
Check if two SortOptions represent reversed orderings.
optional_ordering_try_from_protoproto
Counterpart of optional_ordering_try_to_proto: an empty list decodes as None.
optional_ordering_try_to_protoproto
Serialize an optional LexOrdering, encoding None as an empty list.
options_compatible
Returns whether the given two SortOptions are compatible. Here, compatibility means that they are either exactly equal, or they differ only in whether NULL values come in first/last, which is immaterial because the column in question is not nullable (specified by the nullable parameter).
sort_exprs_try_from_protoproto
Reconstruct a sequence of sort expressions from the flat PhysicalSortExprNode list, the counterpart of sort_exprs_try_to_proto.
sort_exprs_try_to_protoproto
Serialize a sequence of sort expressions into the flat PhysicalSortExprNode list the wire format uses for an ordering.