pub struct ArrowBytesViewMap<V>{ /* private fields */ }Implementations
Sourceimpl<V> ArrowBytesViewMap<V>
impl<V> ArrowBytesViewMap<V>
pub fn new(output_type: OutputType) -> Self
Sourcepub fn take(&mut self) -> Self
pub fn take(&mut self) -> Self
Return the contents of this map and replace it with a new empty map with the same output type
Sourcepub fn insert_if_new<MP, OP>(
&mut self,
values: &ArrayRef,
make_payload_fn: MP,
observe_payload_fn: OP,
)
pub fn insert_if_new<MP, OP>( &mut self, values: &ArrayRef, make_payload_fn: MP, observe_payload_fn: OP, )
Inserts each value from values into the map, invoking payload_fn for
each value if not already present, deferring the allocation of the
payload until it is needed.
Note that this is different than a normal map that would replace the existing entry
Arguments:
values: array whose values are inserted
make_payload_fn: invoked for each value that is not already present
to create the payload, in order of the values in values
observe_payload_fn: invoked once, for each value in values, that was
already present in the map, with corresponding payload value.
Returns
The payload value for the entry, either the existing value or the newly inserted value
Safety:
Note that make_payload_fn and observe_payload_fn are only invoked
with valid values from values, not for the NULL value.
Sourcepub fn into_state(self) -> ArrayRef
pub fn into_state(self) -> ArrayRef
Converts this set into a StringViewArray, or BinaryViewArray,
containing each distinct value
that was inserted. This is done without copying the values.
The values are guaranteed to be returned in the same order in which they were first seen.
Sourcepub fn non_null_len(&self) -> usize
pub fn non_null_len(&self) -> usize
Number of non null entries